#!perl

use Test::More tests => 6;
use Test::Exception;

use File::Basename;

use App::Env;

use Env::Path;

my $ROOT;

{
    local %ENV = %ENV;
    delete $ENV{APP_ENV_SAOTRACE_ROOT};
    delete $ENV{APP_ENV_SAOTRACE_DB};
    App::Env->import( 'SAOTrace', { Cache => 0 } );
    (my $setup) = Env::Path->PATH->Whence( 'saotrace_setup.sh' );
    ok ( -f $setup , "found setup script" );

    if ( $setup )
    {
	$ROOT = dirname(dirname( $setup ) );
    }

}

{
    local %ENV = %ENV;
    dies_ok {
	    App::Env->import( 'SAOTrace', { Cache => 0,
				    AppOpts => { Version => 'badversion' } } )
	   } 'bad version';
}

{
    local %ENV = %ENV;
    $ENV{APP_ENV_SAOTRACE_ROOT} = 'BADROOT';
    dies_ok {
	    App::Env->import( 'SAOTrace', { Cache => 0 } )
	   } 'bad root env';
}

{
    local %ENV = %ENV;
    delete $ENV{APP_ENV_SAOTRACE_ROOT};
    dies_ok {
	    App::Env->import( 'SAOTrace', { Cache => 0,
					    AppOpts => { Root => 'BADROOT' }
					  } )
	   } 'bad root opt';
}

SKIP:
{
    skip 'unable to determine default SAOTRACE_ROOT', 1 unless $ROOT;

    local %ENV = %ENV;
    $ENV{APP_ENV_SAOTRACE_ROOT} = $ROOT;
    dies_ok {
	    App::Env->import( 'SAOTrace', { Cache => 0,
					    AppOpts => { Root => 'BADROOT' }
					  } )
	   } 'good root env, bad root opt';
}

SKIP:
{
    skip 'unable to determine default SAOTRACE_ROOT', 1 unless $ROOT;

    local %ENV = %ENV;
    $ENV{APP_ENV_SAOTRACE_ROOT} = 'BADROOT';
    lives_ok {
	    App::Env->import( 'SAOTrace', { Cache => 0,
					    AppOpts => { Root => $ROOT }
					  } )
	   } 'bad root env, good root opt';
}
